@@ -7,9 +7,9 @@
 setMethod ("has.RGB" , "SpatRaster",
 	function(x, strict=TRUE) {
 		if (strict) {
-			x@cpp$rgbtype == "rgb"
+			x@ptr$rgbtype == "rgb"
 		} else {
-			x@cpp$rgbtype != ""
+			x@ptr$rgbtype != ""
 		}
 	}
 )
@@ -18,13 +18,13 @@ setMethod ("has.RGB" , "SpatRaster",
 setMethod("set.RGB", signature(x="SpatRaster"),
 	function(x, value=1:3, type="rgb") {
 		if (is.null(value[1]) || is.na(value[1]) || any(value < 1)) {
-			x@cpp$removeRGB()
+			x@ptr$removeRGB()
 		} else {
 			stopifnot(all(value %in% 1:nlyr(x)))
 			if (length(value) == 3) {
-				x@cpp$setRGB(value[1]-1, value[2]-1, value[3]-1, -99, type)
+				x@ptr$setRGB(value[1]-1, value[2]-1, value[3]-1, -99, type)
 			} else if (length(value) == 4) {
-				x@cpp$setRGB(value[1]-1, value[2]-1, value[3]-1, value[4]-1, type)
+				x@ptr$setRGB(value[1]-1, value[2]-1, value[3]-1, value[4]-1, type)
 			} else {
 				error("set.RGB", "value must have length 3 or 4")
 			}
@@ -36,7 +36,7 @@ setMethod("set.RGB", signature(x="SpatRaster"),
 
 setMethod("RGB<-", signature(x="SpatRaster"),
 	function(x, ..., type="rgb", value) {
-		x@cpp <- x@cpp$deepcopy()
+		x@ptr <- x@ptr$deepcopy()
 		set.RGB(x, value, type)
 		x
 	}
@@ -44,8 +44,8 @@ setMethod("RGB<-", signature(x="SpatRaster"),
 
 setMethod("RGB", signature(x="SpatRaster"),
 	function(x) {
-		if (x@cpp$rgb) {
-			x@cpp$getRGB() + 1
+		if (x@ptr$rgb) {
+			x@ptr$getRGB() + 1
 		} else {
 			return(NULL)
 		}
@@ -135,7 +135,7 @@ rgb2col <- function(x, value, stretch=NULL, grays=FALSE, NAzero=FALSE, filename=
 
 	if (grays) {
 		opt <- spatOptions(filename, overwrite, ...)
-		x@cpp <- x@cpp$rgb2col(0, 1, 2, opt)
+		x@ptr <- x@ptr$rgb2col(0, 1, 2, opt)
 		return(messages(x, "colorize"))
 	}
 
@@ -143,15 +143,16 @@ rgb2col <- function(x, value, stretch=NULL, grays=FALSE, NAzero=FALSE, filename=
 	v <- median_cut(stats::na.omit(v))
 
 	a <- aggregate(v[,-c(1:2)], list(v[,1]), median)
-	if (n==3) {
-		a$cols <- grDevices::rgb(a[,2], a[,3], a[,4], maxColorValue=255)
-	} else {
-		a$cols <- grDevices::rgb(a[,2], a[,3], a[,4], a[,5], maxColorValue=255)
-	}
-	m <- merge(v[,1:2], a[, c(1,n+2)], by=1)
+#	if (n==3) {
+#		a$cols <- grDevices::rgb(a[,2], a[,3], a[,4], maxColorValue=255)
+#	} else {
+#		a$cols <- grDevices::rgb(a[,2], a[,3], a[,4], a[,5], maxColorValue=255)
+#	}
+	m <- merge(v[,1:2], a, by=1)
+	m[,1] <- m[,1] - 1
 	r <- rast(x, 1)
-	r[m$id] <- m$group - 1
-	coltab(r) <- a$cols
+	r[m$id] <- m$group
+	coltab(r) <- m[,-2]
 	if (filename != "") {
 		r <- writeRaster(r, filename, overwrite, ...)
 	}
@@ -193,17 +194,17 @@ setMethod("colorize", signature(x="SpatRaster"),
 		to <- tolower(to)
 		if (to %in% c("hsi", "hsl", "hsv")) {
 			opt <- spatOptions(filename, overwrite, ...)
-			x@cpp <- x@cpp$rgb2hsx(to, opt)
+			x@ptr <- x@ptr$rgb2hsx(to, opt)
 		} else if (to == "rgb") {
 			if (nlyr(x) == 1) {
 				return(terra_col2rgb(x, alpha=alpha, filename=filename, overwrite=overwrite, ...))
 			} else {
 				opt <- spatOptions(filename, overwrite, ...)
-				x@cpp <- x@cpp$hsx2rgb(opt)
+				x@ptr <- x@ptr$hsx2rgb(opt)
 			}
 		} else if (to == "hsl") {
 			opt <- spatOptions(filename, overwrite, ...)
-			x@cpp <- x@cpp$hsx2rgb(to, opt)
+			x@ptr <- x@ptr$hsx2rgb(to, opt)
 		} else if (to == "col") {
 			return(rgb2col(x, stretch=stretch, grays=grays, NAzero=NAzero, filename=filename, overwrite=overwrite, ...))
 		}
