@@ -135,16 +135,21 @@ make_extract_index <- function(v, vmx, name="i") {
 
 
 
-.extract_cell <- function(x, i, drop=TRUE) {
+.extract_cell <- function(x, i, drop=TRUE, raw=FALSE) {
 	if (!drop) {
 		rc <- rowColFromCell(x, i)
 		e <- ext_from_rc(x, min(rc[,1]), max(rc[,1]), min(rc[,2]), max(rc[,2]))
-		crop(x, e)
+		y <- crop(x, e)
+		y[-cellFromXY(y, xyFromCell(x, i))] <- NA
+		y
 	} else {
-		e <- x@pnt$extractCell(i-1)
-		messages(x, "extract")
+		e <- x@ptr$extractCell(i-1)
+		x <- messages(x, "extract")
 		e <- do.call(cbind, e)
 		colnames(e) <- names(x)
+		if (raw) {
+			return(e)
+		}
 		.makeDataFrame(x, e)
 	}
 }
@@ -152,7 +157,7 @@ make_extract_index <- function(v, vmx, name="i") {
 
 .extract_cell_layer <- function(x, i, lyrs, drop) {
 	if (drop) {
-		e <- x@pnt$extractCell(i-1)
+		e <- x@ptr$extractCell(i-1)
 		messages(x, "extract")
 		e <- do.call(cbind, e)
 		colnames(e) <- names(x)
