@@ -29,7 +29,7 @@ setMethod("merge", signature(x="SpatRaster", y="SpatRaster"),
 	function(x, y, ..., first=TRUE, na.rm=TRUE, filename="", overwrite=FALSE, wopt=list()) {
 		rc <- sprc(x, y, ...)
 		opt <- spatOptions(filename, overwrite, wopt=wopt)
-		x@pnt <- rc@pnt$merge(first[1], na.rm, opt)
+		x@ptr <- rc@ptr$merge(first[1], na.rm, opt)
 		messages(x, "merge")
 	}
 )
@@ -39,7 +39,7 @@ setMethod("merge", signature(x="SpatRasterCollection", "missing"),
 	function(x, first=TRUE, na.rm=TRUE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
 		out <- rast()
-		out@pnt <- x@pnt$merge(first[1], na.rm, opt)
+		out@ptr <- x@ptr$merge(first[1], na.rm, opt)
 		messages(out, "merge")
 	}
 )
@@ -53,7 +53,7 @@ setMethod("mosaic", signature(x="SpatRaster", y="SpatRaster"),
 		}
 		opt <- spatOptions(filename, overwrite, wopt=wopt)
 		rc <- sprc(x, y, ...)
-		x@pnt <- rc@pnt$mosaic(fun, opt)
+		x@ptr <- rc@ptr$mosaic(fun, opt)
 		messages(x, "mosaic")
 	}
 )
@@ -66,7 +66,7 @@ setMethod("mosaic", signature(x="SpatRasterCollection", "missing"),
 		if (!inherits(fun, "character")) {
 			error("mosaic", "function 'fun' is not valid")
 		}
-		out@pnt <- x@pnt$mosaic(fun, opt)
+		out@ptr <- x@ptr$mosaic(fun, opt)
 		messages(out, "mosaic")
 	}
 )
