@@ -3,19 +3,19 @@
 
 setMethod("geomtype", signature(x="SpatVector"),
 	function(x){
-		x@cpp$type()
+		x@ptr$type()
 	}
 )
 setMethod("geomtype", signature(x="SpatVectorProxy"),
 	function(x){
-		x@cpp$v$type()
+		x@ptr$v$type()
 	}
 )
 
 
 setMethod("datatype", signature(x="SpatVector"),
 	function(x){
-		x@cpp$df$get_datatypes()
+		x@ptr$df$get_datatypes()
 	}
 )
 
@@ -48,17 +48,19 @@ setMethod("geomtype", signature(x="Spatial"),
 )
 
 setMethod("geom", signature(x="SpatVector"),
-	function(x, wkt=FALSE, hex=FALSE, df=FALSE, list=FALSE, xnm="x", ynm="y"){
+	function(x, wkt=FALSE, hex=FALSE, wkb=FALSE, df=FALSE, list=FALSE, xnm="x", ynm="y"){
 		if (hex) {
-			x@cpp$hex()
+			x@ptr$hex()
 		} else if (wkt) {
-			x@cpp$getGeometryWKT()
+			x@ptr$getGeometryWKT()
 			# or via geos with
-			# x@cpp$wkt()
+			# x@ptr$wkt()
 		} else if (list) {
-			x@cpp$get_geometryList(xnm, ynm)
-		} else {
-			g <- x@cpp$get_geometry()
+			x@ptr$get_geometryList(xnm, ynm)
+		} else if (wkb) {
+			x@ptr$wkb_raw()
+		}	else {
+			g <- x@ptr$get_geometry()
 			g <- do.call(cbind, g)
 			colnames(g) <- c("geom", "part", "x", "y", "hole")[1:ncol(g)]
 			if (df) {
@@ -75,14 +77,14 @@ setMethod("crds", signature(x="SpatVector"),
 		if (list) {
 			gt <- geomtype(x) 
 			if (gt == "lines") {
-				x@cpp$linesNA()
+				x@ptr$linesNA()
 			} else if (gt == "polygons") {
-				x@cpp$polygonsList()			
+				x@ptr$polygonsList()			
 			} else {
-				x@cpp$coordinates()
+				x@ptr$coordinates()
 			}
 		} else {
-			g <- x@cpp$coordinates()
+			g <- x@ptr$coordinates()
 			g <- do.call(cbind, g)
 			colnames(g) <- c("x", "y")
 			if (df) {
@@ -99,7 +101,7 @@ setMethod("crds", signature(x="SpatRaster"),
 	function(x, df=FALSE, na.rm=TRUE, na.all=FALSE){
 #		crds( as.points(x, values=(hasValues(x) || (na.rm)), na.rm=na.rm, na.all=na.all), df=df)
 		opt <- spatOptions()
-		out <- x@cpp$crds(na.rm, na.all, opt)
+		out <- x@ptr$crds(na.rm, na.all, opt)
 		messages(x)
 		if (df) {
 			out <- data.frame(out)
@@ -120,15 +122,15 @@ setMethod("dim", signature(x="SpatVector"),
 
 setMethod("dim", signature(x="SpatVectorProxy"),
 	function(x){
-		c(x@cpp$v$geom_count, x@cpp$v$ncol())
+		c(x@ptr$v$geom_count, x@ptr$v$ncol())
 	}
 )
 
 
 as.data.frame.SpatVector <- function(x, row.names=NULL, optional=FALSE, geom=NULL, ...) {
-	d <- .getSpatDF(x@cpp$df, ...)
+	d <- .getSpatDF(x@ptr$df, ...)
 	# fix empty names
-	colnames(d)[1:ncol(x)] <- x@cpp$names
+	colnames(d)[1:ncol(x)] <- x@ptr$names
 	if (!is.null(geom)) {
 		geom <- match.arg(toupper(geom), c("WKT", "HEX", "XY"))
 		if (geom == "XY") {
@@ -156,7 +158,7 @@ setMethod("as.data.frame", signature(x="SpatVector"), as.data.frame.SpatVector)
 
 get.data.frame <- function(x) {
 	v <- vect()
-	v@cpp <- x@cpp$v
+	v@ptr <- x@ptr$v
 	d <- as.data.frame(v)
 	d[0,,drop=FALSE]
 }
@@ -171,7 +173,7 @@ setMethod("as.list", signature(x="SpatVector"), as.list.SpatVector)
 
 setMethod ("expanse", "SpatVector",
 	function(x, unit="m", transform=TRUE) {
-		a <- x@cpp$area(unit, transform, double());
+		a <- x@ptr$area(unit, transform, double());
 		x <- messages(x, "expanse");
 		return(abs(a))
 	}
@@ -180,7 +182,7 @@ setMethod ("expanse", "SpatVector",
 
 setMethod("perim", signature(x="SpatVector"),
 	function(x) {
-		p <- x@cpp$length();
+		p <- x@ptr$length();
 		x <- messages(x, "perim");
 		return(p)
 	}
@@ -188,7 +190,7 @@ setMethod("perim", signature(x="SpatVector"),
 
 setMethod("length", signature(x="SpatVector"),
 	function(x) {
-		x@cpp$size()
+		x@ptr$size()
 	}
 )
 
@@ -196,11 +198,11 @@ setMethod("length", signature(x="SpatVector"),
 setMethod("fillHoles", signature(x="SpatVector"),
 	function(x, inverse=FALSE) {
 		if (inverse) {
-			x@cpp <- x@cpp$get_holes()
+			x@ptr <- x@ptr$get_holes()
 		} else {
-			x@cpp <- x@cpp$remove_holes()
+			x@ptr <- x@ptr$remove_holes()
 		}
-		messages(x)
+		messages(x, "fillHoles")
 	}
 )
 
@@ -208,7 +210,7 @@ setMethod("fillHoles", signature(x="SpatVector"),
 
 #setMethod("eliminate", signature(x="SpatVector"),
 #	function(x, y) {
-#		x@cpp <- x@cpp$eliminate(y@cpp)
+#		x@ptr <- x@ptr$eliminate(y@ptr)
 #		messages(x)
 #	}
 #)
@@ -218,11 +220,11 @@ setMethod("fillHoles", signature(x="SpatVector"),
 setMethod("centroids", signature(x="SpatVector"),
 	function(x, inside=FALSE) {
 		if (inside) {
-			x@cpp <- x@cpp$point_on_surface(TRUE)
+			x@ptr <- x@ptr$point_on_surface(TRUE)
 		} else {
-			x@cpp <- x@cpp$centroid(TRUE)
+			x@ptr <- x@ptr$centroid(TRUE)
 		}
-		messages(x)
+		messages(x, "centroids")
 	}
 )
 
@@ -230,8 +232,8 @@ setMethod("centroids", signature(x="SpatVector"),
 
 setMethod("densify", signature(x="SpatVector"),
 	function(x, interval, equalize=TRUE, flat=FALSE) {
-		x@cpp <- x@cpp$densify(interval, equalize, flat)
-		messages(x)
+		x@ptr <- x@ptr$densify(interval, equalize, flat)
+		messages(x, "densify")
 	}
 )
 
@@ -243,7 +245,7 @@ setMethod("normalize.longitude", signature(x="SpatVector"),
 		x[[fname]] <- 1:nrow(x)
 		d <- values(x)
 		out <- x[,fname]
-		out@cpp <- out@cpp$normalize_longitude()
+		out@ptr <- out@ptr$normalize_longitude()
 		out <- messages(out)
 		a <- aggregate(out, fname, count=FALSE)
 		if (nc > 0) {
