@@ -53,7 +53,7 @@ setMethod("subset", signature(x="SpatRaster"),
 		if (negate) subset = -subset
 		subset <- positive_indices(subset, nlyr(x), TRUE, "subset")
 		opt <- spatOptions(filename, overwrite, ...)
-		x@pnt <- x@pnt$subset(subset-1, opt)
+		x@ptr <- x@ptr$subset(subset-1, opt)
 		messages(x, "subset")
 	}
 )
@@ -101,7 +101,10 @@ setMethod("subset", signature(x="SpatVector"),
 			r <- if (missing(subset)) {
 					TRUE
 				} else {
-					r <- eval(substitute(subset), d, parent.frame())
+					e <- substitute(subset)
+					# r <- eval(e, d, parent.frame())
+					# for #1600
+					r <- eval(e, d, globalenv())
 					if (!is.logical(r)) error("subset", "argument 'subset' must be logical")
 					r & !is.na(r)
 				}
@@ -110,7 +113,8 @@ setMethod("subset", signature(x="SpatVector"),
 				} else {
 					nl <- as.list(seq_along(d))
 					names(nl) <- names(d)
-					eval(substitute(select), nl, parent.frame())
+					# eval(substitute(select), nl, parent.frame())
+					eval(substitute(select), nl, globalenv())
 				}
 			x <- x[r, v, drop=drop]
 		} else {
@@ -140,10 +144,10 @@ setMethod("subset", signature(x="SpatVector"),
 			i <- 0
 		}
 	}
-	x@pnt <- x@pnt$subset_cols(i-1)
+	x@ptr <- x@ptr$subset_cols(i-1)
 	x <- messages(x, "subset")
 	if (drop) {	# drop geometry
-		.getSpatDF(x@pnt$df)
+		.getSpatDF(x@ptr$df)
 	} else {
 		x
 	}
@@ -153,7 +157,7 @@ setMethod("subset", signature(x="SpatVector"),
 setMethod("[", c("SpatVector", "numeric", "missing"),
 function(x, i, j, ... , drop=FALSE) {
 	i <- positive_indices(i, nrow(x), TRUE, "`[`")
-	x@pnt <- x@pnt$subset_rows(i-1)
+	x@ptr <- x@ptr$subset_rows(i-1)
 	x <- messages(x, "[")
 	if (drop) {
 		as.data.frame(x)
@@ -172,7 +176,7 @@ function(x, i, j, drop=FALSE) {
 setMethod("[", c("SpatVector", "logical", "missing"),
 function(x, i, j, drop=FALSE) {
 	i <- which(rep_len(i, nrow(x)))
-	x@pnt <- x@pnt$subset_rows(i-1)
+	x@ptr <- x@ptr$subset_rows(i-1)
 	x <- messages(x, "[")
 	if (drop) {
 		as.data.frame(x)
@@ -185,8 +189,8 @@ setMethod("[", c("SpatVector", "numeric", "numeric"),
 function(x, i, j, drop=FALSE) {
 	i <- positive_indices(i, nrow(x), TRUE, "`[`")
 	j <- positive_indices(j, ncol(x), TRUE, "`[`")
-	p <- x@pnt$subset_rows(i-1)
-	x@pnt <- p$subset_cols(j-1)
+	p <- x@ptr$subset_rows(i-1)
+	x@ptr <- p$subset_cols(j-1)
 	x <- messages(x, "'['")
 	if (drop) {
 		as.data.frame(x)
@@ -199,7 +203,7 @@ function(x, i, j, drop=FALSE) {
 setMethod("[", c("SpatVector", "missing", "numeric"),
 function(x, i, j, drop=FALSE) {
 	j <- positive_indices(j, ncol(x), TRUE, "`[`")
-	x@pnt <- x@pnt$subset_cols(j-1)
+	x@ptr <- x@ptr$subset_cols(j-1)
 	x <- messages(x, "[")
 	if (drop) {
 		as.data.frame(x)
