@@ -25,14 +25,20 @@ yearweek <- function(d) {
 	paste0(yy, w)
 }
 
+setMethod("has.time", signature(x="SpatRaster"),
+	function(x) {
+		x@ptr$hasTime
+	}
+)
+
 
 setMethod("timeInfo", signature(x="SpatRaster"),
 	function(x) {
-		time <- x@cpp$hasTime
+		time <- x@ptr$hasTime
 		if (time) {
-			step <- x@cpp$timestep
+			step <- x@ptr$timestep
 			if (step == "seconds") {
-				data.frame(time=time, step=step, zone=x@cpp$timezone)
+				data.frame(time=time, step=step, zone=x@ptr$timezone)
 			} else {
 				data.frame(time=time, step=step, zone="")
 			}
@@ -51,9 +57,9 @@ setMethod("timeInfo", signature(x="SpatRasterDataset"),
 
 
 time_as_seconds <- function(x) {
-	d <- x@cpp$time
+	d <- x@ptr$time
 	d <- strptime("1970-01-01", "%Y-%m-%d", tz="UTC") + d
-	tz <- x@cpp$timezone
+	tz <- x@ptr$timezone
 	if (!(tz %in% c("", "UTC"))) {
 		attr(d, "tzone") = tz
 	}
@@ -63,11 +69,11 @@ time_as_seconds <- function(x) {
 
 setMethod("time", signature(x="SpatRaster"),
 	function(x, format="") {
-		if (!x@cpp$hasTime) {
+		if (!x@ptr$hasTime) {
 			return(rep(NA, nlyr(x)))
 		}
-		d <- x@cpp$time
-		tstep <- x@cpp$timestep
+		d <- x@ptr$time
+		tstep <- x@ptr$timestep
 		if (format != "") {
 			if ((format == "months") && (tstep == "years")) {
 				error("time", "cannot extract months from years-time")
@@ -84,7 +90,7 @@ setMethod("time", signature(x="SpatRaster"),
 		} 
 		if (tstep == "seconds") {
 			d <- strptime("1970-01-01", "%Y-%m-%d", tz="UTC") + d
-			tz <- x@cpp$timezone
+			tz <- x@ptr$timezone
 			if (!(tz %in% c("", "UTC"))) {
 				attr(d, "tzone") = tz
 			}
@@ -139,7 +145,7 @@ setMethod("time<-", signature(x="SpatRaster"),
 			tstep <- ""
 		}
 		if (is.null(value)) {
-			x@cpp$setTime(0[0], "remove", "")
+			x@ptr$setTime(0[0], "remove", "")
 			return(x)
 		}
 		if (inherits(value, "character")) {
@@ -177,14 +183,14 @@ setMethod("time<-", signature(x="SpatRaster"),
 				if (is.numeric(value)) {
 					value <- posix_from_ym(value, "6")
 				} else {
-					value <- as.integer(strftime(value, format = "%Y"))
+					value <- as.integer(strftime(value, format = "%Y", tz=tzone))
 					value <- posix_from_ym(value, "6")
 				}
 			} else if (tstep == "months") {
 				if (is.numeric(value)) {
 					value <- floor(value)
 				} else {
-					value <- as.integer(strftime(value, format = "%m"))
+					value <- as.integer(strftime(value, format = "%m", tz=tzone))
 				}
 				if (!all(value %in% 1:12)) {
 					error("date<-", "months should be between 1 and 12")
@@ -195,8 +201,8 @@ setMethod("time<-", signature(x="SpatRaster"),
 					y <- as.integer(substr(value, 1, 4))
 					m <- value - (y * 100)
 				} else {
-					y <- as.integer(strftime(value, format = "%Y"))
-					m <- as.integer(strftime(value, format = "%m"))
+					y <- as.integer(strftime(value, format = "%Y", tz=tzone))
+					m <- as.integer(strftime(value, format = "%m", tz=tzone))
 				}
 				if (!all(m %in% 1:12)) {
 					error("date<-", "months should be between 1 and 12")
@@ -210,7 +216,7 @@ setMethod("time<-", signature(x="SpatRaster"),
 				stept <- "raw"
 			}
 		}
-		if (!x@cpp$setTime(as.numeric(value), stept, tzone)) {
+		if (!x@ptr$setTime(as.numeric(value), stept, tzone)) {
 			error("time<-", "cannot set these values")
 		}
 		return(x)
@@ -250,7 +256,7 @@ setMethod("time<-", signature(x="SpatRasterDataset"),
 
 setMethod("depth", signature(x="SpatRaster"),
 	function(x) {
-		x@cpp$depth
+		x@ptr$depth
 	}
 )
 
@@ -258,11 +264,11 @@ setMethod("depth", signature(x="SpatRaster"),
 setMethod("depth<-", signature(x="SpatRaster"),
 	function(x, value)  {
 		if (is.null(value)) {
-			x@cpp$setDepth(0[0])
+			x@ptr$setDepth(0[0])
 			return(x)
 		}
 		value <- as.numeric(value)
-		if (! x@cpp$setDepth(value)) {
+		if (! x@ptr$setDepth(value)) {
 			error("depth<-", "cannot set these  values")
 		}
 		return(x)
@@ -283,7 +289,7 @@ setMethod("linearUnits", signature(x="SpatVector"),
 
 setMethod("units", signature(x="SpatRaster"),
 	function(x) {
-		x@cpp$units
+		x@ptr$units
 	}
 )
 
@@ -294,7 +300,7 @@ setMethod("units<-", signature(x="SpatRaster"),
 		} else {
 			value <- as.character(value)
 		}
-		if (! x@cpp$set_units(value)) {
+		if (! x@ptr$set_units(value)) {
 			error("units<-", "cannot set these  values")
 		}
 		return(x)
@@ -304,14 +310,14 @@ setMethod("units<-", signature(x="SpatRaster"),
 
 setMethod("units", signature(x="SpatRasterDataset"),
 	function(x) {
-		x@cpp$units
+		x@ptr$units
 	}
 )
 
 setMethod("units<-", signature(x="SpatRasterDataset"),
 	function(x, value)  {
 		value <- as.character(value)
-		x@cpp$units <- value
+		x@ptr$units <- value
 		return(x)
 	}
 )
