@@ -20,6 +20,7 @@
 #include "recycle.h"
 #include "math_utils.h"
 #include "vecmath.h"
+#include <cmath>
 
 //#include "modal.h"
 
@@ -401,8 +402,8 @@ SpatRaster SpatRaster::arith(std::vector<double> x, std::string oper, bool rever
 		return(arith(x[0], oper, reverse, falseNA, opt));
 	}
 
-	unsigned innl = nlyr();
-	unsigned outnl = innl;
+	size_t innl = nlyr();
+	size_t outnl = innl;
 
 	if (x.size() > innl) {
 		outnl = x.size();
@@ -445,7 +446,7 @@ SpatRaster SpatRaster::arith(std::vector<double> x, std::string oper, bool rever
 		return out;
 	}
 
-	unsigned nc = ncol();
+	size_t nc = ncol();
 	recycle(x, outnl);
 
 	for (size_t i = 0; i < out.bs.n; i++) {
@@ -455,9 +456,9 @@ SpatRaster SpatRaster::arith(std::vector<double> x, std::string oper, bool rever
 			recycle(v, outnl * out.bs.nrows[i] * nc);
 		}
 		//std::vector<double> vv;
-		unsigned off = out.bs.nrows[i] * nc;
+		size_t off = out.bs.nrows[i] * nc;
 		for (size_t j=0; j<outnl; j++) {
-			unsigned s = j * off;
+			size_t s = j * off;
 			if (std::isnan(x[j])) {
 				for (size_t k=0; k<off; k++) {
 					v[s+k] = NAN;
@@ -634,12 +635,12 @@ SpatRaster SpatRaster::arith_m(std::vector<double> x, std::string oper, std::vec
 		return out;
 	}
 
-	unsigned nc = ncol();
+	size_t nc = ncol();
 	
 	for (size_t i = 0; i < out.bs.n; i++) {
 		std::vector<double> v;
 		readBlock(v, out.bs, i);
-		unsigned off = out.bs.nrows[i] * nc;
+		size_t off = out.bs.nrows[i] * nc;
 		for (size_t j=0; j<nl; j++) {
 			size_t s = j * off;
 			size_t d = j * dim[0];
@@ -972,6 +973,20 @@ SpatRaster SpatRaster::atan_2(SpatRaster x, SpatOptions &opt) {
 }
 
 
+/* 
+// no NAN handling
+template <typename T>
+std::vector<T> operator|(const std::vector<T>& a, const std::vector<T>& b) {
+    std::vector<T> result;
+    result.reserve(a.size());
+    std::transform(a.begin(), a.end(), b.begin(), std::back_inserter(result), std::logical_or<T>());
+	for (size_t i=0; i<a.size(); i++) {
+		if (std::isnan(a[i]) || std::isnan(b[i])) {
+			result[i] = NAN;
+		}
+	}
+    return result;
+}
 
 template <typename T>
 std::vector<T> operator&(const std::vector<T>& a, const std::vector<T>& b) {
@@ -985,22 +1000,43 @@ std::vector<T> operator&(const std::vector<T>& a, const std::vector<T>& b) {
 	}
     return result;
 }
+*/
 
-
-template <typename T>
-std::vector<T> operator|(const std::vector<T>& a, const std::vector<T>& b) {
-    std::vector<T> result;
-    result.reserve(a.size());
-    std::transform(a.begin(), a.end(), b.begin(), std::back_inserter(result), std::logical_or<T>());
+inline void logical_and(std::vector<double>& a, const std::vector<double>& b) {
 	for (size_t i=0; i<a.size(); i++) {
-		if (std::isnan(a[i]) || std::isnan(b[i])) {
-			result[i] = NAN;
+		if (std::isnan(a[i])) {
+			if (!std::isnan(b[i]) && (b[i] != 1)) {
+				a[i] = 0; // NA & false = false
+			}	
+		} else if (std::isnan(b[i])) {
+			a[i] = (a[i] != 1) ? 0 : NAN;
+
+		} else {
+			a[i] = (a[i]==1) && (b[i]==1);
 		}
 	}
-    return result;
 }
 
 
+
+inline void logical_or(std::vector<double>& a, const std::vector<double>& b) {
+	for (size_t i=0; i<a.size(); i++) {
+		if (std::isnan(a[i])) {
+			if (b[i] == 1) {
+				a[i] = 1; // NA | true = true
+			}	
+		} else {
+			if (std::isnan(b[i])) {
+				a[i] = (a[i] == 1) ? 1 : NAN; // NA | true = true
+			} else {
+				a[i] = (a[i]==1) || (b[i]==1);
+			}
+		}
+	}
+}
+
+
+
 SpatRaster SpatRaster::isnot(bool falseNA, SpatOptions &opt) {
 	SpatRaster out = geometry();
 	out.setValueType(3);
@@ -1077,11 +1113,9 @@ SpatRaster SpatRaster::logic(SpatRaster x, std::string oper, SpatOptions &opt) {
 		x.readBlock(b, out.bs, i);
 		recycle(a, b);
 		if (oper == "&") {
-			a = a & b;
+			logical_and(a, b); // replaces a
 		} else if (oper == "|") {
-			a = a | b;
-		} else {
-			// stop
+			logical_or(a, b); // replaces a
 		}
 		if (!out.writeBlock(a, i)) return out;
 
@@ -1094,11 +1128,18 @@ SpatRaster SpatRaster::logic(SpatRaster x, std::string oper, SpatOptions &opt) {
 
 
 
-SpatRaster SpatRaster::logic(bool x, std::string oper, SpatOptions &opt) {
+SpatRaster SpatRaster::logic(double x, std::string oper, SpatOptions &opt) {
 
 	SpatRaster out = geometry();
 	out.setValueType(3);
 
+	std::vector<std::string> f {"&", "|", "istrue", "isfalse"};
+	if (std::find(f.begin(), f.end(), oper) == f.end()) {
+		out.setError("unknown logic function");
+		return out;
+	}
+
+
 	if (!readStart()) {
 		out.setError(getError());
 		return(out);
@@ -1112,20 +1153,51 @@ SpatRaster SpatRaster::logic(bool x, std::string oper, SpatOptions &opt) {
 	for (size_t i = 0; i < out.bs.n; i++) {
 		std::vector<double> a;
 		readBlock(a, out.bs, i);
+		// x = NAN
 		if (std::isnan(x)) {
-			for(double& d : a)  d = NAN;
+			if (oper == "&") {
+				for (size_t j=0; j<a.size(); j++) {
+					if ((!std::isnan(a[j])) && (a[j] != 1)) {
+						a[j] = 0;
+					} else {
+						a[j] = NAN;						
+					}
+				}
+			} else if (oper == "|") {
+				for (size_t j=0; j<a.size(); j++) {
+					if (a[j] != 1) {
+						a[j] = 1;
+					} else {
+						a[j] = NAN;						
+					}
+				}
+			} else {
+				for(double& d : a)  d = NAN;
+			}
+		// x != NAN	
 		} else if (oper == "&") {
-			for(double& d : a)  d = (d==1) & x;
+			bool b = x;
+			for (size_t j=0; j<a.size(); j++) {
+				if (std::isnan(a[j])) {
+					a[j] = !b ? 0 : NAN;	
+				} else {
+					a[j] = (a[j] == 1) && b;
+				}
+			}
 		} else if (oper == "|") {
-			for(double& d : a)  d = (d==1) | x;
+			bool b = x;
+			if (b) {
+				for(double& d : a) d = 1;
+			} else {
+				for(double& d : a) {
+					d = std::isnan(d) ? NAN : (d==1);
+				}
+			}
 		} else if (oper == "istrue") {
 			for(double& d : a)  d = d==1 ? 1 : 0;
-		} else if (oper == "isfalse") {
+		} else { // if (oper == "isfalse") {
 			for(double& d : a)  d = d!=1 ? 1 : 0;
-		} else {
-			out.setError("unknown operator: " + oper);
-			return out;
-		}
+		} 
 		if (!out.writeBlock(a, i)) return out;
 	}
 	out.writeStop();
@@ -1134,6 +1206,55 @@ SpatRaster SpatRaster::logic(bool x, std::string oper, SpatOptions &opt) {
 }
 
 
+SpatRaster SpatRaster::logic(std::vector<double> x, std::string oper, SpatOptions &opt) {
+
+	if (x.size() == 1) {
+		return logic(x[0], oper, opt);
+	}
+
+	SpatRaster out = geometry();
+	out.setValueType(3);
+
+	if (x.size() == 0) {
+		out.setError("logical operator has length 0");
+		return out;
+	}
+	std::vector<std::string> f {"&", "|", "istrue", "isfalse"};
+	if (std::find(f.begin(), f.end(), oper) == f.end()) {
+		out.setError("unknown logic function");
+		return out;
+	}
+
+	if (!readStart()) {
+		out.setError(getError());
+		return(out);
+	}
+
+  	if (!out.writeStart(opt, filenames())) {
+		readStop();
+		return out;
+	}
+	std::vector<double> v, m;
+	for (size_t i = 0; i < out.bs.n; i++) {
+		std::vector<double> a;
+		readBlock(a, out.bs, i);
+		recycle(x, a.size());
+		if (oper == "&") {
+			logical_and(a, x);
+		} else if (oper == "|") {
+			logical_or(a, x);
+		} else if (oper == "istrue") {
+			for(double& d : a)  d = std::isnan(d) ? NAN : (d==1 ? 1 : 0);
+		} else { //if (oper == "isfalse") {
+			for(double& d : a)  d = std::isnan(d) ? NAN : (d!=1 ? 1 : 0);
+		} 
+		if (!out.writeBlock(a, i)) return out;
+	}
+	out.writeStop();
+	readStop();
+	return(out);
+}
+
 SpatRaster SpatRaster::cum(std::string fun, bool narm, SpatOptions &opt) {
 
 	SpatRaster out = geometry();
@@ -1158,9 +1279,9 @@ SpatRaster SpatRaster::cum(std::string fun, bool narm, SpatOptions &opt) {
 		readStop();
 		return out;
 	}
-	unsigned nl = out.nlyr();
+	size_t nl = out.nlyr();
 	std::vector<double> v(nl);
-	unsigned nc;
+	size_t nc;
 	for (size_t i = 0; i < out.bs.n; i++) {
 		std::vector<double> a;
 		readBlock(a, out.bs, i);
@@ -1231,14 +1352,14 @@ SpatRaster SpatRaster::summary_numb(std::string fun, std::vector<double> add, bo
 		readStop();
 		return out;
 	}
-	unsigned nl = nlyr();
+	size_t nl = nlyr();
 	std::vector<double> v(nl);
 	if (!add.empty()) v.insert( v.end(), add.begin(), add.end() );
 
 	for (size_t i = 0; i < out.bs.n; i++) {
 		std::vector<double> a;
 		readBlock(a, out.bs, i);
-		unsigned nc = out.bs.nrows[i] * out.ncol();
+		size_t nc = out.bs.nrows[i] * out.ncol();
 		std::vector<double> b(nc);
 		for (size_t j=0; j<nc; j++) {
 			for (size_t k=0; k<nl; k++) {
@@ -1292,14 +1413,14 @@ SpatRaster SpatRaster::modal(std::vector<double> add, std::string ties, bool nar
 	std::default_random_engine rgen(seed);
 	std::uniform_real_distribution<double> dist (0.0,1.0);
 
-	unsigned nl = nlyr();
+	size_t nl = nlyr();
 	std::vector<double> v(nl);
 	v.insert( v.end(), add.begin(), add.end() );
 
 	for (size_t i = 0; i < out.bs.n; i++) {
 		std::vector<double> a;
 		readBlock(a, out.bs, i);
-		unsigned nc = out.bs.nrows[i] * out.ncol();
+		size_t nc = out.bs.nrows[i] * out.ncol();
 		std::vector<double> b(nc);
 		for (size_t j=0; j<nc; j++) {
 			for (size_t k=0; k<nl; k++) {
@@ -1333,14 +1454,14 @@ SpatRaster SpatRaster::range(std::vector<double> add, bool narm, SpatOptions &op
 		readStop();
 		return out;
 	}
-	unsigned nl = nlyr();
+	size_t nl = nlyr();
 	std::vector<double> v(nl);
 	v.insert( v.end(), add.begin(), add.end() );
 
 	for (size_t i = 0; i < out.bs.n; i++) {
 		std::vector<double> a;
 		readBlock(a, out.bs, i);
-		unsigned nc = out.bs.nrows[i] * out.ncol();
+		size_t nc = out.bs.nrows[i] * out.ncol();
 		std::vector<double> b(nc * 2);
 		for (size_t j=0; j<nc; j++) {
 			for (size_t k=0; k<nl; k++) {
@@ -1363,9 +1484,9 @@ SpatRaster SpatRaster::range(std::vector<double> add, bool narm, SpatOptions &op
 SpatRaster SpatRasterStack::summary_numb(std::string fun, std::vector<double> add, bool narm, SpatOptions &opt) {
 
 	std::vector<unsigned> vnl = nlyr();
-	unsigned nl = vmax(vnl, false);
+	size_t nl = vmax(vnl, false);
 	SpatRaster out = ds[0].geometry(nl);
-	unsigned ns = nsds();
+	size_t ns = nsds();
 
 	if (fun == "range") {
 		out.setError("parallel range not implemented, use min and max");
@@ -1401,7 +1522,7 @@ SpatRaster SpatRasterStack::summary_numb(std::string fun, std::vector<double> ad
 
 	std::vector<std::vector<double>> a(ns);
 	for (size_t i=0; i < out.bs.n; i++) {
-		unsigned nc = out.bs.nrows[i] * out.ncol() * nl;
+		size_t nc = out.bs.nrows[i] * out.ncol() * nl;
 		for (size_t j=0; j < ns; j++) {
 			ds[j].readBlock(a[j], out.bs, i);
 			recycle(a[j], nc);
@@ -1763,7 +1884,7 @@ SpatRaster SpatRaster::isinfinite(bool falseNA, SpatOptions &opt) {
 
 std::vector<std::vector<double>> SpatRaster::where(std::string what, bool values, SpatOptions &opt) {
 
-	unsigned nl = nlyr();
+	size_t nl = nlyr();
 	std::vector<std::vector<double>> out(nl);
 
 	std::vector<std::string> f {"min", "max"};
