@@ -43,16 +43,28 @@ std::vector<double> rcValue(std::vector<double> &d, const int& nrow, const int&
 std::vector<double> SpatRaster::focal_values(std::vector<unsigned> w, double fillvalue, int_64 row, int_64 nrows, SpatOptions &ops) {
 
 	if (nlyr() > 1) {
-		std::vector<unsigned> lyr = {0};
+		std::vector<size_t> lyr = {0};
 		SpatRaster s = subset(lyr, ops);
 		s.focal_values(w, fillvalue, row, nrows, ops);
 	}
 
-	if ((w[0] % 2 == 0) || (w[1] % 2 == 0)) {
-		setError("weights matrix must have uneven sides");
-		std::vector<double> d;
-		return(d);
+	std::vector<double> error;
+	if (w.size() < 2) {
+		setError("weights matrix must have more than one side");
+		return(error);
 	}
+
+	for (size_t i=0; i<w.size(); i++) {
+		if (w[i] % 2 == 0) {
+			setError("weights matrix must have uneven sides");
+			return(error);
+		}
+		if (w[i] < 1) {
+			setError("weights matrix must have dimensions larger than 0");
+			return(error);
+		}
+	}
+
 	const bool global = is_global_lonlat();
 
 	int_64 nr = nrow();
