@@ -22,7 +22,6 @@
 #include "recycle.h"
 #include "string_utils.h"
 
-
 void callbck(void *item, void *userdata) { // callback function for tree selection
 	std::vector<size_t> *ret = (std::vector<size_t> *) userdata;
 	ret->push_back(*((size_t *) item));
@@ -95,7 +94,21 @@ std::vector<std::string> SpatVector::wkb() {
 	return out;
 }
 
-	
+std::vector<std::vector<unsigned char>> SpatVector::wkb_raw() {
+	GEOSContextHandle_t hGEOSCtxt = geos_init();
+	std::vector<GeomPtr> g = geos_geoms(this, hGEOSCtxt);
+	std::vector<std::vector<unsigned char>> out; 
+	size_t len = 0;
+	for (size_t i = 0; i < g.size(); i++) {
+		unsigned char *hex = GEOSGeomToWKB_buf_r(hGEOSCtxt, g[i].get(), &len);
+		std::vector<unsigned char> raw; 
+		raw = std::vector<unsigned char>(hex, hex+len);
+		out.push_back(raw);
+		free(hex);
+	}
+	geos_finish(hGEOSCtxt);
+	return out;
+}	
 	
 std::vector<std::string> SpatVector::hex() {
 	GEOSContextHandle_t hGEOSCtxt = geos_init();
@@ -214,7 +227,7 @@ SpatVector SpatVector::make_valid2() {
 		if (r != NULL) {
 			if (!GEOSisEmpty_r(hGEOSCtxt, r)) {
 				x[i] = geos_ptr(r, hGEOSCtxt);
-				ids.push_back(i);
+				//ids.push_back(i);
 			} else {
 				GEOSGeom_destroy_r(hGEOSCtxt, r);
 			}
@@ -224,11 +237,11 @@ SpatVector SpatVector::make_valid2() {
 	out = coll.get(0);
 	geos_finish(hGEOSCtxt);
 	out.srs = srs;
-	if (ids.size() != n) {
-		out.df = df.subset_rows(out.df.iv[0]);
-	} else {
+//	if (ids.size() != n) {
+//		out.df = df.subset_rows(out.df.iv[0]);
+//	} else {
 		out.df = df;
-	}
+//	}
 #endif
 	return out;
 }
