@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2022  Robert J. Hijmans
+// Copyright (c) 2018-2023  Robert J. Hijmans
 //
 // This file is part of the "spat" library.
 //
@@ -224,8 +224,8 @@ double modal_value(std::vector<double> values, unsigned ties, bool narm, std::de
 				tieCount = 1;
 			} else if (counts[i] == counts[maxCount]) {
 				tieCount++;
-				double rand = dist(rgen);
-				if (rand < (1 / tieCount)) {
+				double randnr = dist(rgen);
+				if (randnr < (1 / tieCount)) {
 					maxCount = i;
 				}
 			}
@@ -248,3 +248,5 @@ double modal_value(std::vector<double> values, unsigned ties, bool narm, std::de
     return values[maxCount];
 }
 
+
+
