@@ -408,6 +408,25 @@ std::vector<unsigned> SpatVector::nullGeoms(){
 	return ids;
 }
 
+std::vector<bool> SpatVector::naGeoms(){
+	std::vector<bool> nas(geoms.size(), true);
+	for (size_t i=0; i<geoms.size(); i++) {
+		if (geoms[i].gtype == null) continue;
+		for (size_t j=0; j<geoms[i].parts.size(); j++) {
+			for (size_t k=0; k<geoms[i].parts[j].x.size(); k++) {
+				nas[i] = false;
+				if (std::isnan(geoms[i].parts[j].x[k]) || 
+						std::isnan(geoms[i].parts[j].y[k])) {
+					nas[i] = true;
+					goto contin;
+				}
+			}
+			// check holes
+		}
+		contin: {};
+	}
+	return nas;
+}
 
 
 bool SpatVector::replaceGeom(SpatGeom p, unsigned i) {
@@ -867,6 +886,32 @@ void SpatVector::setPointsDF(SpatDataFrame &x, std::vector<unsigned> geo, std::s
 	df = x;
 }
 
+void SpatVector::setLinesStartEnd(std::vector<double> &x, std::string crs) {
+	size_t n = x.size() / 4;
+	if (n == 0) return;
+	size_t n2 = 2 * n;
+	size_t n3 = 3 * n;
+	SpatGeom g;
+	g.gtype = lines;
+	SpatPart p({x[0], x[n]},{x[n2], x[n3]});
+	g.addPart(p);
+	geoms.resize(n, g);
+	for (size_t i=1; i<n; i++) {
+		geoms[i].parts[0].x[0] = x[i];
+		geoms[i].parts[0].x[1] = x[i+n];
+		geoms[i].parts[0].y[0] = x[i+n2];
+		geoms[i].parts[0].y[1] = x[i+n3];
+		geoms[i].extent.xmin = *std::min_element(geoms[i].parts[0].x.begin(), geoms[i].parts[0].x.end());
+		geoms[i].extent.xmax = *std::max_element(geoms[i].parts[0].x.begin(), geoms[i].parts[0].x.end());
+		geoms[i].extent.ymin = *std::min_element(geoms[i].parts[0].y.begin(), geoms[i].parts[0].y.end());
+		geoms[i].extent.ymax = *std::max_element(geoms[i].parts[0].y.begin(), geoms[i].parts[0].y.end());
+	}
+	computeExtent();
+	setSRS( {crs} );
+}
+
+
+
 
 SpatVector SpatVector::subset_rows(std::vector<int> range) {
 
@@ -1024,6 +1069,12 @@ SpatVector SpatVector::cbind(SpatDataFrame d) {
 
 
 SpatVector SpatVector::as_points(bool multi, bool skiplast) {
+	if (nrow() == 0) {
+		SpatVector v;
+		v.setError("input has no geometries");
+		return v;
+	}
+	
 	if (geoms[0].gtype == points) {
 		SpatVector v = *this;
 		v.addWarning("returning a copy");
@@ -1426,3 +1477,4 @@ std::vector<std::vector<std::vector<std::vector<double>>>> SpatVector::polygonsL
 }
 
 
+
