@@ -245,7 +245,7 @@ SpatVector SpatVector::elongate(double length, bool flat) {
 	return out;
 }
 
-
+#include "Rcpp.h"
 
 SpatVectorCollection SpatVector::split(std::string field) {
 
@@ -272,6 +272,7 @@ SpatVectorCollection SpatVector::split(std::string field) {
 		v.df = df.subset_rows(r);
 		out.push_back(v);
 	}
+	out.names = uv.as_string(0);
 	return out;
 }
 
